#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gnutls
version:              0.2
visibility:           public
id:                   gnutls-0.2-REPxR1vQ4L65EKPdDYzCC
key:                  gnutls-0.2-REPxR1vQ4L65EKPdDYzCC
license:              GPL-3.0-only
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-gnutls/
synopsis:             Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.

    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.

category:             Network
abi:                  bc1454a88dbba751ff31e1977bb06ed1
exposed:              True
exposed-modules:      Network.Protocol.TLS.GNU
hidden-modules:
    Network.Protocol.TLS.GNU.ErrorT Network.Protocol.TLS.GNU.Foreign

import-dirs:          /usr/lib/ghc-8.10.5/site-local/gnutls-0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/gnutls-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/gnutls-0.2
hs-libraries:         HSgnutls-0.2-REPxR1vQ4L65EKPdDYzCC
extra-libraries:      gnutls gnutls
include-dirs:         /usr/include/p11-kit-1
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    monads-tf-0.1.0.3-Ej5CyhAaIcR5aDT198RxUj transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html:         /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

